@@ -34,6 +34,11 @@ class QuotaTemplate(NetBoxModel):
         verbose_name = 'Device Quota'
     )
 
+    description = models.CharField(
+        max_length=500,
+        blank=True
+    )
+
     comments = models.TextField(
         blank=True
     )
@@ -45,4 +50,4 @@ class QuotaTemplate(NetBoxModel):
         return str(f"{self.template_name}")
 
     def get_absolute_url(self):
-        return reverse('plugins:netbox_project_quota:quotatemplate', args=[self.pk])
+        return reverse('plugins:netbox_manage_project:quotatemplate', args=[self.pk])
